<?php
namespace Drupal\data_api;

require_once dirname(__FILE__) . '/drupal7_mocks.php';

class DataTest extends \PHPUnit_Framework_TestCase
{
    public function testItemLevel()
    {
        global $entity;
        $subject = array('und' => array(array('value' => 'Scott Johnson')));
        $node = (object) array(
            "field_name" => $subject,
            'type'       => 'person',
        );
        $entity = $node;
        $control = $subject['und'][0]['value'];
        $this->data->setEntityType('node');
        $this->assertSame($control, $this->data->get($node, 'field_name.0.value'));

        // This will test the callback and the default.
        $this->assertSame('JACK', $this->data->get($node, 'field_name.0.value', 'Jack', function ($value, $default) {
            return strtoupper($default);
        }));
    }

    public function testDeltaLevel()
    {
        global $entity;
        $subject = array('und' => array(array('value' => 'Scott Johnson')));
        $node = (object) array(
            "field_name" => $subject,
            'type'       => 'person',
        );
        $entity = $node;
        $control = $subject['und'][0];
        $this->data->setEntityType('node');
        $this->assertSame($control, $this->data->get($node, 'field_name.0'));

        // Test the callback
        $this->assertSame(json_encode($control), $this->data->get($node, 'field_name.0', null, function ($value) {
            return json_encode($value);
        }));
    }

    public function testFieldLevel()
    {
        global $entity;
        $subject = array('und' => array(array('value' => 'Scott Johnson')));
        $node = (object) array(
            "field_name" => $subject,
            'type'       => 'person',
        );
        $entity = $node;
        $control = $subject['und'];
        $this->data->setEntityType('node');
        $this->assertSame($control, $this->data->get($node, 'field_name'));

        // Test the callback
        $this->assertSame(json_encode($control), $this->data->get($node, 'field_name', null, function ($value) {
            return json_encode($value);
        }));
    }

    public function testEmptySubject()
    {
        $this->assertSame('froggy', $this->data->get(array(), 'field', 'froggy'));
    }

    public function testNid()
    {
        global $entity;
        $subject = (object) array('nid' => 27);
        $entity = $subject;
        $this->assertSame(27, $this->data->setEntityType('node')
                                         ->get($subject, 'nid'));
    }

    public function testNidNoEntityType()
    {
        global $entity;
        $subject = (object) array('nid' => 27);
        $entity = $subject;
        $this->assertSame(27, $this->data->get($subject, 'nid'));
    }

    public function setUp()
    {
        $this->data = new Data;
    }
}
